@@ -7,7 +7,6 @@ import cv2
 import numpy as np
 import paddle
 from paddle import inference
-from os.path import expanduser
 from PIL import Image, ImageDraw, ImageFont
 
 
@@ -16,8 +15,6 @@ def str2bool(v):
 
 
 def init_args():
-    PROJECT_ROOT = os.path.join(expanduser("~"), ".cache")
-
     parser = argparse.ArgumentParser()
     # params for prediction engine
     parser.add_argument("--use_gpu", type=str2bool, default=False)
@@ -31,9 +28,7 @@ def init_args():
     # params for text detector
     parser.add_argument("--image_dir", type=str)
     parser.add_argument("--det_algorithm", type=str, default="DB")
-    parser.add_argument(
-        "--det_model_dir", type=str, default=os.path.join(PROJECT_ROOT, "ch_PP-OCRv3_det_infer/")
-    )
+    parser.add_argument("--det_model_dir", type=str, default="./src/deprem_ocr/ch_PP-OCRv3_det_infer/")
     parser.add_argument("--det_limit_side_len", type=float, default=960)
     parser.add_argument("--det_limit_type", type=str, default="max")
 
@@ -71,16 +66,12 @@ def init_args():
 
     # params for text recognizer
     parser.add_argument("--rec_algorithm", type=str, default="SVTR_LCNet")
-    parser.add_argument(
-        "--rec_model_dir", type=str, default=os.path.join(PROJECT_ROOT, "ch_PP-OCRv3_rec_infer/")
-    )
+    parser.add_argument("--rec_model_dir", type=str, default="./src/deprem_ocr/ch_PP-OCRv3_rec_infer/")
     parser.add_argument("--rec_image_shape", type=str, default="3, 48, 320")
     parser.add_argument("--rec_batch_num", type=int, default=6)
     parser.add_argument("--max_text_length", type=int, default=25)
     parser.add_argument(
-        "--rec_char_dict_path",
-        type=str,
-        default=os.path.join(PROJECT_ROOT, "ppocr/ppocr_keys_v1.txt"),
+        "--rec_char_dict_path", type=str, default="./src/deprem_ocr/ppocr/ppocr_keys_v1.txt"
     )
     parser.add_argument("--use_space_char", type=str2bool, default=True)
     parser.add_argument("--drop_score", type=float, default=0.5)
